/*
 * demi-logger
 * https://github.com/chrisenytc/demi-logger
 *
 * Copyright (c) 2013 Christopher EnyTC
 * Licensed under the MIT license.
 */

'use strict';

/**
 * Module Dependencies
 */

var prettyjson = require('prettyjson');
require('colors');

/**
@class DemiLogger
 */

/*
 * Public Methods
 */

/**
 * Method responsible for manage demi.js logging
 *
 * @example
 *
 *     logger(tokens, req, res);
 *
 * @method logger
 * @param {Object} tokens Express.logger tokens
 * @param {Object} req Middleware request
 * @param {Object} res Middleware response
 */

module.exports = function (tokens, req, res) {
  //Date
  var date = new Date();
  //Logger
  var protocol = req.protocol.toUpperCase().bold;
  var ip = tokens['remote-addr'](req, res);
  var method = req.method;
  var mili = tokens['response-time'](req, res).cyan + 'ms'.cyan;
  var routePath = tokens.url(req, res).green;
  var status = String(tokens.status(req, res));
  var by = req.xhr ? 'Ajax'.bold.green : 'No Ajax';

  var showMethod = function () {
    //storage
    var result;
    //Check
    switch (req.method) {
    case 'GET':
      result = '[' + method.green + ']' + ' --> ' + ip.green;
      break;
    case 'POST':
      result = '[' + method.yellow + ']' + ' --> ' + ip.yellow;
      break;
    case 'PUT':
      result = '[' + method.cyan + ']' + ' --> ' + ip.cyan;
      break;
    case 'DELETE':
      result = '[' + method.red + ']' + ' --> ' + ip.red;
      break;
    }

    //return
    return result;
  };

  var showStatus = function () {
    //storage
    var result;
    //Check
    switch (status) {
    case '200':
      result = status.green + ' OK'.green;
      break;
    case '301':
      result = status.cyan + ' Moved Permanently'.cyan;
      break;
    case '302':
      result = status.cyan + ' Found'.cyan;
      break;
    case '304':
      result = status.cyan + ' Not Modified'.cyan;
      break;
    case '400':
      result = status.red + ' Bad Request'.red;
      break;
    case '401':
      result = status.yellow + ' Unauthorized'.yellow;
      break;
    case '403':
      result = status.yellow + ' Forbidden'.yellow;
      break;
    case '404':
      result = status.yellow + ' Not Found'.yellow;
      break;
    case '500':
      result = status.red + ' Internal Server Error'.red;
      break;
    case '503':
      result = status.red + ' Service Unavailable'.red;
      break;
    default:
      result = status.red;
      break;
    }

    //return
    return result;
  };

  //Logger
  console.log('[ ' + protocol + ' ]' + ' ' + showMethod() + ' --> ' + by + ' --> ' + mili + ' --> ' + showStatus() + ' ==> ' + routePath);
  //Received data
  if (req.body) {
    console.log();
    console.log('[ ' + 'Received'.green.bold + ' ] ==> ');
    console.log(prettyjson.render({
      body: req.body,
      params: req.params,
      query: req.query
    }));
    console.log();
  }

};
